@@ -26,10 +26,11 @@ urlpatterns = [
 ]
 
 try:
-
     registration.register_json_schema_resource_type()
     registration.register_json_ld_resource_type()
+    registration.register_indexing_policy_resource_type()
     urlpatterns.extend(registration.JSON_SCHEMA_REGISTRATION_.urls)
     urlpatterns.extend(registration.JSON_LD_REGISTRATION_.urls)
+    urlpatterns.extend(registration.INDEXING_POLICY_REGISTRATION_.urls)
 except (OperationalError, ProgrammingError) as e:
     logging.error(e)
